<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation type="unfinished">MA</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="unfinished">DI</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="unfinished">WO</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="unfinished">DO</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="unfinished">VR</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="unfinished">ZA</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="unfinished">ZO</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Haze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fair</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NNE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NNW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WSW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WNW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Bezig laden...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ bezig ophalen weerbericht ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>vandaag</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Vochtigheid</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Luchtdruk</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Wind</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Zichtbaarheid</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Lucht Koelte</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV Index</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>komende dagen</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>MIN</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>MAX</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>vandaag</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>morgen</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Verwachtingen voor</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Doppler Radar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Weerkaart niet beschikbaar</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Configuratie &quot;Het Weer&quot;</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Druk &apos;i&apos; om op te slaan - druk escape om te annuleren</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation> is ongeldig)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>   Locatie niet ingesteld, lees de README</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Bezig configureren MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Gebruik de rechterpijl om uw conversie-eenheid te kiezen</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Eenheden</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Aggressiviteit</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Configuratie opgeslaan...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Bezig ophalen weerbericht...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Kies uw locatie met de rechterpijl...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Kies uw aggressiviteit met de rechterpijl...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation> 1  Hoge Snelheid Verbinding</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation> 8  Gemiddelde Snelheid Verbinding</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation> 15 Lage Snelheid Verbinding</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Ophalen initieel weerbericht...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Bijwerken weerbericht...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Kalm</translation>
    </message>
    <message>
        <source> at </source>
        <translation> aan </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Ongelimiteerd</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation> (minimaal)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation> (gematigd)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation> (hoog)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation> (extreem)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Vandaag maximaal </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> en minimaal </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. De vochtigheid bedraagt </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% en de wind</translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>kalm.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> komt aan </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation> mph uit het </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> km/h uit het </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> De zichtbaarheid is vandaag ongelimiteerd. </translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> De zichtbaarheid is niet gekend.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> De zichtbaarheid bedraagt </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> mijl.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="obsolete">ZO</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Zondag</translation>
    </message>
    <message>
        <source>MON</source>
        <translation type="obsolete">MA</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="obsolete">DI</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="obsolete">WO</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="obsolete">DO</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="obsolete">VR</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="obsolete">ZA</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Fout in datum</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Morgen is het maximaal </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Verwachtingen: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Voorspelling van: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Bezig Bijwerken...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(Niet alle informatie is beschikbaar)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID Entered *** Use a valid area id.</source>
        <translation type="obsolete">*** Ongeldige Locatie ingevoerd *** Gebruik een geldige ID.</translation>
    </message>
    <message>
        <source>Weather Data Not Available</source>
        <translation type="obsolete">Weerbericht Niet Beschikbaar</translation>
    </message>
    <message>
        <source>!!! Timeout Limit !!! Change aggressiveness level.</source>
        <translation type="obsolete">!!! Timeout !!! Wijzig uw aggressiviteit.</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">Doppler Radar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
